<!-- PROJECT LOGO -->
<br />
<p align="center">

<h3 align="center">whooshy</h3>

  <p align="center">
    A fork of <a href="https://github.com/mchaput/whoosh"><strong>Whoosh</strong></a> project
    <br />
    <a href="https://matchup.ufop.br/"><strong>Used by matchup »</strong></a>
    <br />
    <br />
    <a href="https://github.com/matchup-ir/whooshy/issues">Report Bug</a>
    ·
    <a href="https://github.com/matchup-ir/whooshy/issues">Request Feature</a>
  </p>
</p>



<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#integration">Integration</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## About The Project

### Built With

## Getting Started

## Usage


## Roadmap

The project is in the early stages of development. Thus, feel free to contribute and help WhooshY to grow up!

Actual Roadmap is:
1. Implement indexing
2. Implement matching / scoring
3. Integrate with matchup

See the [open issues](https://github.com/matchup-ir/whooshy/issues) for a list of proposed features (and known issues).

**OBS**: To propose new features or report bugs, check out the correct templates.

<!-- CONTRIBUTING -->
## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<!-- LICENSE -->
## License

This software is licensed under the terms of the simplified BSD (A.K.A. "two clause" or "FreeBSD") license. See LICENSE for information.

<!-- CONTACT -->
## Contact

Marcos Pontes - mfprezende@gmail.com

Project Link: [https://github.com/matchup-ir/whooshy](https://github.com/matchup-ir/whooshy)
